define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "aquest trim.",
	"field-quarter-short-relative+1": "el trim. que ve",
	"field-tue-relative+-1": "dimarts passat",
	"field-year": "any",
	"field-wed-relative+0": "aquest dimecres",
	"field-wed-relative+1": "dimecres que ve",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "el mes passat",
	"field-tue-narrow-relative+0": "aquest dt.",
	"field-tue-narrow-relative+1": "dt. que ve",
	"field-thu-short-relative+0": "aquest dj.",
	"field-day-short-relative+-1": "ahir",
	"field-thu-short-relative+1": "dj. que ve",
	"field-day-relative+0": "avui",
	"field-day-short-relative+-2": "abans-d’ahir",
	"field-day-relative+1": "demà",
	"field-week-narrow-relative+0": "aquesta setm.",
	"field-day-relative+2": "demà passat",
	"field-week-narrow-relative+1": "la setm. que ve",
	"field-wed-narrow-relative+-1": "dc. passat",
	"field-year-narrow": "any",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "enguany",
	"field-tue-relative+0": "aquest dimarts",
	"field-year-narrow-relative+1": "l’any que ve",
	"field-tue-relative+1": "dimarts que ve",
	"field-weekdayOfMonth": "dia de la setmana del mes",
	"field-second-short": "s",
	"field-weekdayOfMonth-narrow": "dia de la setm. del mes",
	"field-week-relative+0": "aquesta setmana",
	"field-month-relative+0": "aquest mes",
	"field-week-relative+1": "la setmana que ve",
	"field-month-relative+1": "el mes que ve",
	"field-sun-narrow-relative+0": "aquest dg.",
	"field-mon-short-relative+0": "aquest dl.",
	"field-sun-narrow-relative+1": "dg. que ve",
	"field-mon-short-relative+1": "dl. que ve",
	"field-second-relative+0": "ara",
	"field-weekOfMonth": "setmana del mes",
	"field-month-short": "mes",
	"field-day": "dia",
	"field-dayOfYear-short": "dia de l’any",
	"field-year-relative+-1": "l’any passat",
	"field-sat-short-relative+-1": "ds. passat",
	"field-hour-relative+0": "aquesta hora",
	"field-second-short-relative+0": "ara",
	"field-wed-relative+-1": "dimecres passat",
	"field-sat-narrow-relative+-1": "ds. passat",
	"field-second": "segon",
	"dateFormat-long": "d MMMM U",
	"field-hour-short-relative+0": "aquesta hora",
	"field-quarter": "trimestre",
	"field-week-short": "setm.",
	"field-day-narrow-relative+0": "avui",
	"field-day-narrow-relative+1": "demà",
	"field-day-narrow-relative+2": "demà passat",
	"field-tue-short-relative+0": "aquest dt.",
	"field-tue-short-relative+1": "dt. que ve",
	"field-month-short-relative+-1": "el mes passat",
	"field-mon-relative+-1": "dilluns passat",
	"field-month": "mes",
	"field-day-narrow": "dia",
	"field-minute-short": "min",
	"field-dayperiod": "a. m./p. m.",
	"field-sat-short-relative+0": "aquest ds.",
	"field-sat-short-relative+1": "ds. que ve",
	"dateFormat-medium": "d MMM U",
	"field-second-narrow": "s",
	"field-mon-relative+0": "aquest dilluns",
	"field-mon-relative+1": "dilluns que ve",
	"field-day-narrow-relative+-1": "ahir",
	"field-year-short": "any",
	"field-day-narrow-relative+-2": "abans-d’ahir",
	"field-quarter-relative+-1": "el trimestre passat",
	"field-dayperiod-narrow": "a. m./p. m.",
	"field-week-narrow-relative+-1": "la setm. passada",
	"field-dayOfYear": "dia de l’any",
	"field-sat-relative+-1": "dissabte passat",
	"field-hour": "hora",
	"field-minute-narrow-relative+0": "aquest minut",
	"months-format-wide": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"dateFormat-full": "EEEE, dd MMMM UU",
	"field-month-relative+-1": "el mes passat",
	"field-quarter-short": "trim.",
	"field-sat-narrow-relative+0": "aquest ds.",
	"field-fri-relative+0": "aquest divendres",
	"field-sat-narrow-relative+1": "ds. que ve",
	"field-fri-relative+1": "divendres que ve",
	"field-month-narrow-relative+0": "aquest mes",
	"field-month-narrow-relative+1": "el mes que ve",
	"field-sun-short-relative+0": "aquest dg.",
	"field-sun-short-relative+1": "dg. que ve",
	"field-week-relative+-1": "la setmana passada",
	"field-quarter-short-relative+-1": "el trim. passat",
	"field-minute-short-relative+0": "aquest minut",
	"months-format-abbr": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+0": "aquest trimestre",
	"field-minute-relative+0": "aquest minut",
	"field-quarter-relative+1": "el trimestre que ve",
	"field-wed-short-relative+-1": "dc. passat",
	"dateFormat-short": "d/M/y",
	"field-thu-short-relative+-1": "dj. passat",
	"field-year-narrow-relative+-1": "l’any passat",
	"field-mon-narrow-relative+-1": "dl. passat",
	"field-thu-narrow-relative+-1": "dj. passat",
	"field-tue-narrow-relative+-1": "dt. passat",
	"field-weekOfMonth-short": "setm. del mes",
	"field-wed-short-relative+0": "aquest dc.",
	"months-standAlone-wide": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-wed-short-relative+1": "dc. que ve",
	"field-sun-relative+-1": "diumenge passat",
	"field-second-narrow-relative+0": "ara",
	"field-weekday": "dia de la setmana",
	"field-day-short-relative+0": "avui",
	"field-quarter-narrow-relative+0": "aquest trim.",
	"field-day-short-relative+1": "demà",
	"field-sat-relative+0": "aquest dissabte",
	"field-quarter-narrow-relative+1": "trim. vinent",
	"field-day-short-relative+2": "demà passat",
	"field-sat-relative+1": "dissabte que ve",
	"field-week-short-relative+0": "aquesta setm.",
	"field-week-short-relative+1": "la setm. que ve",
	"months-standAlone-abbr": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-dayOfYear-narrow": "dia de l’any",
	"field-month-short-relative+0": "aquest mes",
	"field-month-short-relative+1": "el mes que ve",
	"field-weekdayOfMonth-short": "dia de la setm. del mes",
	"field-zone-narrow": "fus horari",
	"field-thu-narrow-relative+0": "aquest dj.",
	"field-thu-narrow-relative+1": "dj. que ve",
	"field-sun-narrow-relative+-1": "dg. passat",
	"field-mon-short-relative+-1": "dl. passat",
	"field-thu-relative+0": "aquest dijous",
	"field-thu-relative+1": "dijous que ve",
	"field-fri-short-relative+-1": "dv. passat",
	"field-thu-relative+-1": "dijous passat",
	"field-week": "setmana",
	"field-wed-narrow-relative+0": "aquest dc.",
	"field-wed-narrow-relative+1": "dc. que ve",
	"field-quarter-narrow-relative+-1": "trim. passat",
	"field-year-short-relative+0": "enguany",
	"field-dayperiod-short": "a. m./p. m.",
	"field-year-short-relative+1": "l’any que ve",
	"field-fri-short-relative+0": "aquest dv.",
	"field-fri-short-relative+1": "dv. que ve",
	"field-week-short-relative+-1": "la setm. passada",
	"field-hour-narrow-relative+0": "aquesta hora",
	"field-hour-short": "h",
	"field-zone-short": "fus horari",
	"field-month-narrow": "mes",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "dv. passat",
	"field-year-relative+0": "enguany",
	"field-year-relative+1": "l’any que ve",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "divendres passat",
	"field-tue-short-relative+-1": "dt. passat",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "aquest dl.",
	"field-mon-narrow-relative+1": "dl. que ve",
	"field-year-short-relative+-1": "l’any passat",
	"field-zone": "fus horari",
	"field-weekOfMonth-narrow": "setm. del mes",
	"field-weekday-narrow": "dia de la setm.",
	"field-quarter-narrow": "trim.",
	"field-sun-short-relative+-1": "dg. passat",
	"field-day-relative+-1": "ahir",
	"field-day-relative+-2": "abans-d’ahir",
	"field-weekday-short": "dia de la setm.",
	"field-sun-relative+0": "aquest diumenge",
	"field-sun-relative+1": "diumenge que ve",
	"field-day-short": "dia",
	"field-week-narrow": "setm.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "aquest dv.",
	"field-fri-narrow-relative+1": "dv. que ve"
}
//end v1.x content
);